@@ -1,12 +1,19 @@
 # -*- coding: utf-8 -*-
-from __future__ import (print_function, division,
-                        unicode_literals, absolute_import)
+from __future__ import (
+    print_function,
+    division,
+    unicode_literals,
+    absolute_import
+)
 
+# Std. lib imports.
 import sys
 
-from .natsort import natsorted, regex_and_num_function_chooser
-from ._version import __version__
-from .py23compat import py23_str
+# Local imports.
+from natsort.natsort import natsorted, ns
+from natsort.utils import _regex_and_num_function_chooser
+from natsort._version import __version__
+from natsort.compat.py23 import py23_str
 
 
 def main():
@@ -48,20 +55,33 @@ def main():
         help='Returns in reversed order.')
     parser.add_argument(
         '-t', '--number-type', '--number_type', dest='number_type',
-        choices=('digit', 'int', 'float', 'version', 'ver'), default='float',
+        choices=('digit', 'int', 'float', 'version', 'ver',
+                 'real', 'f', 'i', 'r', 'd'),
+        default='int',
         help='Choose the type of number to search for. "float" will search '
              'for floating-point numbers.  "int" will only search for '
-             'integers. "digit", "version", and "ver" are shortcuts for "int" '
-             'with --nosign.')
+             'integers. "digit", "version", and "ver" are synonyms for "int".'
+             '"real" is a shortcut for "float" with --sign. '
+             '"i" and "d" are synonyms for "int", "f" is a synonym for '
+             '"float", and "r" is a synonym for "real".'
+             'The default is %(default)s.')
     parser.add_argument(
-        '--nosign', default=True, action='store_false', dest='signed',
+        '--nosign', default=False, action='store_false', dest='signed',
         help='Do not consider "+" or "-" as part of a number, i.e. do not '
-             'take sign into consideration.')
+             'take sign into consideration. This is the default.')
+    parser.add_argument(
+        '-s', '--sign', default=False, action='store_true', dest='signed',
+        help='Consider "+" or "-" as part of a number, i.e. '
+             'take sign into consideration. The default is unsigned.')
     parser.add_argument(
         '--noexp', default=True, action='store_false', dest='exp',
         help='Do not consider an exponential as part of a number, i.e. 1e4, '
              'would be considered as 1, "e", and 4, not as 10000.  This only '
              'effects the --number-type=float.')
+    parser.add_argument(
+        '-l', '--locale', action='store_true', default=False,
+        help='Causes natsort to use locale-aware sorting. You will get the '
+             'best results if you install PyICU.')
     parser.add_argument(
         'entries', nargs='*', default=sys.stdin,
         help='The entries to sort. Taken from stdin if nothing is given on '
@@ -70,6 +90,7 @@ def main():
 
     # Make sure the filter range is given properly. Does nothing if no filter
     args.filter = check_filter(args.filter)
+    args.reverse_filter = check_filter(args.reverse_filter)
 
     # Remove trailing whitespace from all the entries
     entries = [e.strip() for e in args.entries]
@@ -135,23 +156,25 @@ def sort_and_print_entries(entries, args):
     """Sort the entries, applying the filters first if necessary."""
 
     # Extract the proper number type.
-    kwargs = {'number_type': {'digit': None,
-                              'version': None,
-                              'ver': None,
-                              'int': int,
-                              'float': float}[args.number_type],
-              'signed': args.signed,
-              'exp': args.exp,
-              'as_path': args.paths,
-              'reverse': args.reverse, }
+    is_float = args.number_type in ('float', 'real', 'f', 'r')
+    signed = args.signed or args.number_type in ('real', 'r')
+    alg = (ns.FLOAT * is_float |
+           ns.SIGNED * signed |
+           ns.NOEXP * (not args.exp) |
+           ns.PATH * args.paths |
+           ns.LOCALE * args.locale)
 
     # Pre-remove entries that don't pass the filtering criteria
     # Make sure we use the same searching algorithm for filtering
     # as for sorting.
     do_filter = args.filter is not None or args.reverse_filter is not None
     if do_filter or args.exclude:
-        inp_options = (kwargs['number_type'], args.signed, args.exp)
-        regex, num_function = regex_and_num_function_chooser[inp_options]
+        inp_options = (ns.FLOAT * is_float |
+                       ns.SIGNED * signed |
+                       ns.NOEXP * (not args.exp),
+                       '.'
+                       )
+        regex, num_function = _regex_and_num_function_chooser[inp_options]
         if args.filter is not None:
             lows, highs = ([f[0] for f in args.filter],
                            [f[1] for f in args.filter])
@@ -171,7 +194,7 @@ def sort_and_print_entries(entries, args):
                                         num_function, regex)]
 
     # Print off the sorted results
-    for entry in natsorted(entries, **kwargs):
+    for entry in natsorted(entries, reverse=args.reverse, alg=alg):
         print(entry)
 
 
