@@ -1,8 +1,11 @@
 # -*- coding: utf-8 -*-
 """This module defines the "ns" enum for natsort."""
-
-from __future__ import (print_function, division,
-                        unicode_literals, absolute_import)
+from __future__ import (
+    print_function,
+    division,
+    unicode_literals,
+    absolute_import
+)
 
 
 class ns(object):
