@@ -5,30 +5,57 @@ from __future__ import unicode_literals
 import sys
 import locale
 import pathlib
+import pytest
 import string
 from math import isnan
 from operator import itemgetter
 from itertools import chain
 from pytest import raises
-from hypothesis import given, assume, example
-from hypothesis.specifiers import sampled_from
 from natsort.ns_enum import ns
-from natsort.utils import _number_extracter, _py3_safe, _natsort_key, _args_to_enum
-from natsort.utils import _float_sign_exp_re, _float_nosign_exp_re, _float_sign_noexp_re
-from natsort.utils import _float_nosign_noexp_re, _int_nosign_re, _int_sign_re, _do_decoding
-from natsort.utils import _path_splitter, _fix_nan
-from natsort.locale_help import use_pyicu, null_string, locale_convert, dumb_sort
-from natsort.py23compat import py23_str
-from slow_splitters import int_splitter, float_splitter, sep_inserter
-
-try:
-    from fastnumbers import fast_float, fast_int, isint
-    import fastnumbers
-    v = list(map(int, fastnumbers.__version__.split('.')))
-    if not (v[0] >= 0 and v[1] >= 5):  # Require >= version 0.5.0.
-        raise ImportError
-except ImportError:
-    from natsort.fake_fastnumbers import fast_float, fast_int, isint
+from natsort.utils import (
+    _number_extracter,
+    _py3_safe,
+    _natsort_key,
+    _args_to_enum,
+    _float_sign_exp_re,
+    _float_nosign_exp_re,
+    _float_sign_noexp_re,
+    _float_nosign_noexp_re,
+    _int_nosign_re,
+    _int_sign_re,
+    _do_decoding,
+    _path_splitter,
+    _fix_nan,
+)
+from natsort.locale_help import locale_convert
+from natsort.compat.py23 import py23_str
+from natsort.compat.locale import (
+    use_pyicu,
+    null_string,
+    dumb_sort,
+)
+from natsort.compat.fastnumbers import (
+    fast_float,
+    fast_int,
+    isint,
+)
+from slow_splitters import (
+    int_splitter,
+    float_splitter,
+    sep_inserter,
+)
+from compat.locale import (
+    load_locale,
+    get_strxfrm,
+    low,
+)
+from compat.hypothesis import (
+    assume,
+    given,
+    example,
+    sampled_from,
+    use_hypothesis,
+)
 
 if sys.version[0] == '3':
     long = int
@@ -36,13 +63,6 @@ if sys.version[0] == '3':
 ichain = chain.from_iterable
 
 
-def load_locale(x):
-    try:
-        locale.setlocale(locale.LC_ALL, str('{}.ISO8859-1'.format(x)))
-    except:
-        locale.setlocale(locale.LC_ALL, str('{}.UTF-8'.format(x)))
-
-
 def test_do_decoding_decodes_bytes_string_to_unicode():
     assert type(_do_decoding(b'bytes', 'ascii')) is py23_str
     assert _do_decoding(b'bytes', 'ascii') == 'bytes'
@@ -156,6 +176,7 @@ def test_py3_safe_with_use_locale_inserts_null_string_between_two_numbers_exampl
     assert _py3_safe([5, 9], True, isint) == [5, null_string, 9]
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([py23_str, int])
 def test_py3_safe_inserts_empty_string_between_two_numbers(x):
     assume(bool(x))
@@ -167,6 +188,7 @@ def test_path_splitter_splits_path_string_by_separator_example():
     assert _path_splitter(z) == list(pathlib.Path(z).parts)
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([sampled_from(string.ascii_letters)])
 def test_path_splitter_splits_path_string_by_separator(x):
     assume(len(x) > 1)
@@ -181,6 +203,7 @@ def test_path_splitter_splits_path_string_by_separator_and_removes_extension_exa
     assert _path_splitter(z) == y[:-1] + [pathlib.Path(z).stem] + [pathlib.Path(z).suffix]
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([sampled_from(string.ascii_letters)])
 def test_path_splitter_splits_path_string_by_separator_and_removes_extension(x):
     assume(len(x) > 2)
@@ -195,6 +218,7 @@ def test_number_extracter_raises_TypeError_if_given_a_number_example():
         assert _number_extracter(50.0, _float_sign_exp_re, *float_nosafe_nolocale_nogroup)
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given(float)
 def test_number_extracter_raises_TypeError_if_given_a_number(x):
     with raises(TypeError):
@@ -205,6 +229,7 @@ def test_number_extracter_includes_plus_sign_and_exponent_in_float_definition_fo
     assert _number_extracter('a5+5.034e-1', _float_sign_exp_re, *float_nosafe_nolocale_nogroup) == ['a', 5.0, 0.5034]
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test_number_extracter_includes_plus_sign_and_exponent_in_float_definition_for_signed_exp_floats(x):
     assume(len(x) <= 10)
@@ -217,6 +242,7 @@ def test_number_extracter_excludes_plus_sign_in_float_definition_but_includes_ex
     assert _number_extracter('a5+5.034e-1', _float_nosign_exp_re, *float_nosafe_nolocale_nogroup) == ['a', 5.0, '+', 0.5034]
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test_number_extracter_excludes_plus_sign_in_float_definition_but_includes_exponent_for_unsigned_exp_floats(x):
     assume(len(x) <= 10)
@@ -229,6 +255,7 @@ def test_number_extracter_includes_plus_and_minus_sign_in_float_definition_but_e
     assert _number_extracter('a5+5.034e-1', _float_sign_noexp_re, *float_nosafe_nolocale_nogroup) == ['a', 5.0, 5.034, 'e', -1.0]
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test_number_extracter_includes_plus_and_minus_sign_in_float_definition_but_excludes_exponent_for_signed_noexp_floats(x):
     assume(len(x) <= 10)
@@ -241,6 +268,7 @@ def test_number_extracter_excludes_plus_sign_and_exponent_in_float_definition_fo
     assert _number_extracter('a5+5.034e-1', _float_nosign_noexp_re, *float_nosafe_nolocale_nogroup) == ['a', 5.0, '+', 5.034, 'e-', 1.0]
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test_number_extracter_excludes_plus_sign_and_exponent_in_float_definition_for_unsigned_noexp_floats(x):
     assume(len(x) <= 10)
@@ -253,6 +281,7 @@ def test_number_extracter_excludes_plus_and_minus_sign_in_int_definition_for_uns
     assert _number_extracter('a5+5.034e-1', _int_nosign_re, *int_nosafe_nolocale_nogroup) == ['a', 5, '+', 5, '.', 34, 'e-', 1]
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 @example([10000000000000000000000000000000000000000000000000000000000000000000000000,
           100000000000000000000000000000000000000000000000000000000000000000000000000,
@@ -267,6 +296,7 @@ def test_number_extracter_includes_plus_and_minus_sign_in_int_definition_for_sig
     assert _number_extracter('a5+5.034e-1', _int_sign_re, *int_nosafe_nolocale_nogroup) == ['a', 5, 5, '.', 34, 'e', -1]
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test_number_extracter_includes_plus_and_minus_sign_in_int_definition_for_signed_ints(x):
     assume(len(x) <= 10)
@@ -278,6 +308,7 @@ def test_number_extracter_inserts_empty_string_between_floats_for_py3safe_option
     assert _number_extracter('a5+5.034e-1', _float_sign_exp_re, *float_safe_nolocale_nogroup) == ['a', 5.0, '', 0.5034]
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test_number_extracter_inserts_empty_string_between_floats_for_py3safe_option(x):
     assume(len(x) <= 10)
@@ -290,6 +321,7 @@ def test_number_extracter_inserts_empty_string_between_ints_for_py3safe_option_e
     assert _number_extracter('a5+5.034e-1', _int_sign_re, *int_safe_nolocale_nogroup) == ['a', 5, '', 5, '.', 34, 'e', -1]
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test_number_extracter_inserts_empty_string_between_ints_for_py3safe_option(x):
     assume(len(x) <= 10)
@@ -313,14 +345,11 @@ def test_number_extracter_doubles_letters_with_lowercase_version_with_grouplette
     assert _number_extracter('A5+5.034E-1', _float_sign_exp_re, *float_nosafe_nolocale_group) == ['aA', 5.0, 0.5034]
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test_number_extracter_doubles_letters_with_lowercase_version_with_groupletters_for_float(x):
     assume(len(x) <= 10)
     assume(not any(type(y) == float and isnan(y) for y in x))
-    try:
-        low = py23_str.casefold
-    except AttributeError:
-        low = py23_str.lower
     s = ''.join(repr(y) if type(y) in (float, long, int) else y for y in x)
     t = float_splitter(s, True, True, False, '')
     t = [''.join([low(z) + z for z in y]) if type(y) != float else y for y in t]
@@ -331,13 +360,10 @@ def test_number_extracter_doubles_letters_with_lowercase_version_with_grouplette
     assert _number_extracter('A5+5.034E-1', _int_nosign_re, *int_nosafe_nolocale_group) == ['aA', 5, '++', 5, '..', 34, 'eE--', 1]
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test_number_extracter_doubles_letters_with_lowercase_version_with_groupletters_for_int(x):
     assume(len(x) <= 10)
-    try:
-        low = py23_str.casefold
-    except AttributeError:
-        low = py23_str.lower
     s = ''.join(repr(y) if type(y) in (float, long, int) else y for y in x)
     t = int_splitter(s, False, False, '')
     t = [''.join([low(z) + z for z in y]) if type(y) not in (int, long) else y for y in t]
@@ -346,58 +372,56 @@ def test_number_extracter_doubles_letters_with_lowercase_version_with_grouplette
 
 def test_number_extracter_extracts_numbers_and_strxfrms_strings_with_use_locale_example():
     load_locale('en_US')
-    if use_pyicu:
-        from natsort.locale_help import get_pyicu_transform
-        from locale import getlocale
-        strxfrm = get_pyicu_transform(getlocale())
-    else:
-        from natsort.locale_help import strxfrm
+    strxfrm = get_strxfrm()
     assert _number_extracter('A5+5.034E-1', _int_nosign_re, *int_nosafe_locale_nogroup) == [strxfrm('A'), 5, strxfrm('+'), 5, strxfrm('.'), 34, strxfrm('E-'), 1]
     locale.setlocale(locale.LC_NUMERIC, str(''))
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test_number_extracter_extracts_numbers_and_strxfrms_strings_with_use_locale(x):
     assume(len(x) <= 10)
     load_locale('en_US')
     s = ''.join(repr(y) if type(y) in (float, long, int) else y for y in x)
     t = int_splitter(s, False, False, null_string)
-    t = [y if i == 0 and y is null_string else locale_convert(y, (fast_int, isint), False) for i, y in enumerate(t)]
-    assert _number_extracter(s, _int_nosign_re, *int_nosafe_locale_nogroup) == t
+    try:  # Account for locale bug on Python 3.2
+        t = [y if i == 0 and y is null_string else locale_convert(y, (fast_int, isint), False) for i, y in enumerate(t)]
+        assert _number_extracter(s, _int_nosign_re, *int_nosafe_locale_nogroup) == t
+    except OverflowError:
+        pass
     locale.setlocale(locale.LC_NUMERIC, str(''))
 
 
 def test_number_extracter_extracts_numbers_and_strxfrms_letter_doubled_strings_with_use_locale_and_groupletters_example():
     load_locale('en_US')
-    if use_pyicu:
-        from natsort.locale_help import get_pyicu_transform
-        from locale import getlocale
-        strxfrm = get_pyicu_transform(getlocale())
-    else:
-        from natsort.locale_help import strxfrm
+    strxfrm = get_strxfrm()
     assert _number_extracter('A5+5.034E-1', _int_nosign_re, *int_nosafe_locale_group) == [strxfrm('aA'), 5, strxfrm('++'), 5, strxfrm('..'), 34, strxfrm('eE--'), 1]
     locale.setlocale(locale.LC_NUMERIC, str(''))
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test_number_extracter_extracts_numbers_and_strxfrms_letter_doubled_strings_with_use_locale_and_groupletters(x):
     assume(len(x) <= 10)
     load_locale('en_US')
     s = ''.join(repr(y) if type(y) in (float, long, int) else y for y in x)
     t = int_splitter(s, False, False, null_string)
-    t = [y if i == 0 and y is null_string else locale_convert(y, (fast_int, isint), True) for i, y in enumerate(t)]
-    assert _number_extracter(s, _int_nosign_re, *int_nosafe_locale_group) == t
+    try:  # Account for locale bug on Python 3.2
+        t = [y if i == 0 and y is null_string else locale_convert(y, (fast_int, isint), True) for i, y in enumerate(t)]
+        assert _number_extracter(s, _int_nosign_re, *int_nosafe_locale_group) == t
+    except OverflowError:
+        pass
     locale.setlocale(locale.LC_NUMERIC, str(''))
 
 
 def test__natsort_key_with_nan_input_transforms_nan_to_negative_inf():
-    assert _natsort_key('nan', None, ns.FLOAT) == (u'', float('-inf'))
-    assert _natsort_key(float('nan'), None, 0) == (u'', float('-inf'))
+    assert _natsort_key('nan', None, ns.FLOAT) == ('', float('-inf'))
+    assert _natsort_key(float('nan'), None, 0) == ('', float('-inf'))
 
 
 def test__natsort_key_with_nan_input_and_NANLAST_transforms_nan_to_positive_inf():
-    assert _natsort_key('nan', None, ns.FLOAT | ns.NANLAST) == (u'', float('+inf'))
-    assert _natsort_key(float('nan'), None, ns.NANLAST) == (u'', float('+inf'))
+    assert _natsort_key('nan', None, ns.FLOAT | ns.NANLAST) == ('', float('+inf'))
+    assert _natsort_key(float('nan'), None, ns.NANLAST) == ('', float('+inf'))
     assert ns.NL == ns.NANLAST
 
 
@@ -405,6 +429,7 @@ def test__natsort_key_with_nan_input_and_NANLAST_transforms_nan_to_positive_inf(
 # They only confirm that _natsort_key uses the above building blocks.
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test__natsort_key_with_float_and_signed_splits_input_into_string_and_signed_float_with_exponent(x):
     assume(len(x) <= 10)
@@ -415,6 +440,7 @@ def test__natsort_key_with_float_and_signed_splits_input_into_string_and_signed_
     assert _natsort_key(s, None, ns.F | ns.S) == tuple(_number_extracter(s, _float_sign_exp_re, *float_nosafe_nolocale_nogroup))
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test__natsort_key_with_real_splits_input_into_string_and_signed_float_with_exponent(x):
     assume(len(x) <= 10)
@@ -424,6 +450,7 @@ def test__natsort_key_with_real_splits_input_into_string_and_signed_float_with_e
     assert _natsort_key(s, None, ns.R) == tuple(_number_extracter(s, _float_sign_exp_re, *float_nosafe_nolocale_nogroup))
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test__natsort_key_with_real_matches_signed_float(x):
     assume(len(x) <= 10)
@@ -432,6 +459,7 @@ def test__natsort_key_with_real_matches_signed_float(x):
     assert _natsort_key(s, None, ns.R) == _natsort_key(s, None, ns.F | ns.S)
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test__natsort_key_with_float_and_signed_and_noexp_splits_input_into_string_and_signed_float_without_exponent(x):
     assume(len(x) <= 10)
@@ -441,6 +469,7 @@ def test__natsort_key_with_float_and_signed_and_noexp_splits_input_into_string_a
     assert _natsort_key(s, None, ns.F | ns.S | ns.N) == tuple(_number_extracter(s, _float_sign_noexp_re, *float_nosafe_nolocale_nogroup))
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test__natsort_key_with_float_and_unsigned_splits_input_into_string_and_unsigned_float(x):
     assume(len(x) <= 10)
@@ -452,6 +481,7 @@ def test__natsort_key_with_float_and_unsigned_splits_input_into_string_and_unsig
     assert _natsort_key(s, None, ns.F) == tuple(_number_extracter(s, _float_nosign_exp_re, *float_nosafe_nolocale_nogroup))
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test__natsort_key_with_float_and_noexp_splits_input_into_string_and_unsigned_float_without_exponent(x):
     assume(len(x) <= 10)
@@ -460,6 +490,7 @@ def test__natsort_key_with_float_and_noexp_splits_input_into_string_and_unsigned
     assert _natsort_key(s, None, ns.F | ns.N) == tuple(_number_extracter(s, _float_nosign_noexp_re, *float_nosafe_nolocale_nogroup))
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test__natsort_key_with_int_splits_input_into_string_and_unsigned_int(x):
     assume(len(x) <= 10)
@@ -473,6 +504,7 @@ def test__natsort_key_with_int_splits_input_into_string_and_unsigned_int(x):
     assert _natsort_key(s, None, ns.I | ns.NOEXP) == tuple(_number_extracter(s, _int_nosign_re, *int_nosafe_nolocale_nogroup))
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test__natsort_key_with_int_splits_and_signed_input_into_string_and_signed_int(x):
     assume(len(x) <= 10)
@@ -482,6 +514,7 @@ def test__natsort_key_with_int_splits_and_signed_input_into_string_and_signed_in
     assert _natsort_key(s, None, ns.SIGNED) == tuple(_number_extracter(s, _int_sign_re, *int_nosafe_nolocale_nogroup))
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test__natsort_key_with_version_or_digit_matches_usigned_int(x):
     assume(len(x) <= 10)
@@ -491,6 +524,7 @@ def test__natsort_key_with_version_or_digit_matches_usigned_int(x):
     assert _natsort_key(s, None, ns.DIGIT) == _natsort_key(s, None, ns.VERSION)
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test__natsort_key_with_key_applies_key_function_before_splitting(x):
     assume(len(x) <= 10)
@@ -499,6 +533,7 @@ def test__natsort_key_with_key_applies_key_function_before_splitting(x):
     assert _natsort_key(s, lambda x: x.upper(), ns.I) == tuple(_number_extracter(s.upper(), _int_nosign_re, *int_nosafe_nolocale_nogroup))
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test__natsort_key_with_tuple_input_returns_nested_tuples(x):
     # Iterables are parsed recursively so you can sort lists of lists.
@@ -509,6 +544,7 @@ def test__natsort_key_with_tuple_input_returns_nested_tuples(x):
     assert _natsort_key((s, s), None, ns.I) == (t, t)
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test__natsort_key_with_tuple_input_but_itemgetter_key_returns_split_second_element(x):
     # A key is applied before recursion, but not in the recursive calls.
@@ -519,6 +555,7 @@ def test__natsort_key_with_tuple_input_but_itemgetter_key_returns_split_second_e
     assert _natsort_key((s, s), itemgetter(1), ns.I) == t
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given(float)
 def test__natsort_key_with_numeric_input_returns_number_with_leading_empty_string(x):
     assume(not isnan(x))
@@ -527,6 +564,7 @@ def test__natsort_key_with_numeric_input_returns_number_with_leading_empty_strin
     assert _natsort_key(x, None, ns.I) == ('', x)
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test__natsort_key_with_TYPESAFE_inserts_spaces_between_numbers(x):
     # Turn on TYPESAFE to put a '' between adjacent numbers
@@ -543,6 +581,7 @@ def test__natsort_key_with_invalid_alg_input_raises_ValueError():
     assert str(err.value) == "_natsort_key: 'alg' argument must be from the enum 'ns', got 1"
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test__natsort_key_with_IGNORECASE_lowercases_text(x):
     assume(len(x) <= 10)
@@ -554,6 +593,7 @@ def test__natsort_key_with_IGNORECASE_lowercases_text(x):
         assert _natsort_key(s, None, ns.IGNORECASE) == tuple(_number_extracter(s.lower(), _int_nosign_re, *int_nosafe_nolocale_nogroup))
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test__natsort_key_with_LOWERCASEFIRST_inverts_text_case(x):
     assume(len(x) <= 10)
@@ -562,12 +602,9 @@ def test__natsort_key_with_LOWERCASEFIRST_inverts_text_case(x):
     assert _natsort_key(s, None, ns.LOWERCASEFIRST) == tuple(_number_extracter(s.swapcase(), _int_nosign_re, *int_nosafe_nolocale_nogroup))
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test__natsort_key_with_GROUPLETTERS_doubles_text_with_lowercase_letter_first(x):
-    try:
-        low = py23_str.casefold
-    except AttributeError:
-        low = py23_str.lower
     assume(len(x) <= 10)
     assume(not any(type(y) == float and isnan(y) for y in x))
     s = ''.join(ichain([repr(y)] if type(y) in (float, long, int) else [low(y), y] for y in x))
@@ -576,12 +613,9 @@ def test__natsort_key_with_GROUPLETTERS_doubles_text_with_lowercase_letter_first
     assert _natsort_key(s, None, ns.GROUPLETTERS) == tuple(''.join(low(z) + z for z in y) if type(y) not in (float, long, int) else y for y in t)
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test__natsort_key_with_GROUPLETTERS_and_LOWERCASEFIRST_inverts_text_first_then_doubles_letters_with_lowercase_letter_first(x):
-    try:
-        low = py23_str.casefold
-    except AttributeError:
-        low = py23_str.lower
     assume(len(x) <= 10)
     assume(not any(type(y) == float and isnan(y) for y in x))
     s = ''.join(ichain([repr(y)] if type(y) in (float, long, int) else [low(y), y] for y in x))
@@ -600,6 +634,7 @@ def test__natsort_key_with_bytes_input_only_applies_LOWERCASEFIRST_or_IGNORECASE
         assert True
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test__natsort_key_with_LOCALE_transforms_floats_according_to_the_current_locale_and_strxfrms_strings(x):
     # Locale aware sorting
@@ -614,6 +649,7 @@ def test__natsort_key_with_LOCALE_transforms_floats_according_to_the_current_loc
     locale.setlocale(locale.LC_NUMERIC, str(''))
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test__natsort_key_with_LOCALE_and_UNGROUPLETTERS_places_space_before_string_with_capital_first_letter(x):
     # Locale aware sorting
@@ -639,6 +675,7 @@ def test__natsort_key_with_LOCALE_and_UNGROUPLETTERS_places_space_before_string_
     locale.setlocale(locale.LC_NUMERIC, str(''))
 
 
+@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
 @given([float, py23_str, int])
 def test__natsort_key_with_UNGROUPLETTERS_does_nothing_without_LOCALE(x):
     assume(len(x) <= 10)
